@@ -37,12 +37,12 @@ namespace disruptive {
 class Redirect : public Action {
  public:
     explicit Redirect(const std::string &action)
-        : Action(action, RunTimeOnlyIfMatchKind),
+        : Action(action),
         m_status(0),
         m_string(nullptr) { }
 
     explicit Redirect(std::unique_ptr<RunTimeString> z)
-        : Action("redirert", RunTimeOnlyIfMatchKind),
+        : Action("redirert"),
             m_status(0),
             m_string(std::move(z)) { }
 
