@@ -37,7 +37,11 @@ bool SetENV::evaluate(RuleWithActions *rule, Transaction *t) {
     auto pair = utils::string::ssplit_pair(colNameExpanded, '=');
     ms_dbg_a(t, 8, "Setting environment variable: "
         + pair.first + " to " + pair.second);
+#ifndef WIN32
     setenv(pair.first.c_str(), pair.second.c_str(), /*overwrite*/ 1);
+#else
+    _putenv_s(pair.first.c_str(), pair.second.c_str());
+#endif
 
     return true;
 }
