@@ -1,6 +1,6 @@
 /*
  * ModSecurity, http://www.modsecurity.org/
- * Copyright (c) 2015 Trustwave Holdings, Inc. (http://www.trustwave.com/)
+ * Copyright (c) 2015 - 2021 Trustwave Holdings, Inc. (http://www.trustwave.com/)
  *
  * You may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
@@ -19,8 +19,8 @@
 #include <string>
 #include <memory>
 
+#include "modsecurity/rules_set.h"
 #include "modsecurity/transaction.h"
-#include "modsecurity/rules.h"
 #include "modsecurity/rule.h"
 #include "src/utils/string.h"
 #include "src/variables/global.h"
@@ -40,7 +40,7 @@ bool SetVar::init(std::string *error) {
 }
 
 
-bool SetVar::evaluate(Rule *rule, Transaction *t) {
+bool SetVar::evaluate(RuleWithActions *rule, Transaction *t) {
     std::string targetValue;
     std::string resolvedPre;
 
@@ -49,21 +49,14 @@ bool SetVar::evaluate(Rule *rule, Transaction *t) {
     }
 
     std::string m_variableNameExpanded;
-    std::vector<const VariableValue *> l;
 
     auto *v = m_variable.get();
-    variables::Tx_DynamicElement *tx = dynamic_cast<
-        variables::Tx_DynamicElement *> (v);
-    variables::Session_DynamicElement *session = dynamic_cast<
-        variables::Session_DynamicElement *> (v);
-    variables::Ip_DynamicElement *ip = dynamic_cast<
-        variables::Ip_DynamicElement *> (v);
-    variables::Resource_DynamicElement *resource = dynamic_cast<
-        variables::Resource_DynamicElement *> (v);
-    variables::Global_DynamicElement *global = dynamic_cast<
-        variables::Global_DynamicElement *> (v);
-    variables::User_DynamicElement *user = dynamic_cast<
-        variables::User_DynamicElement *> (v);
+    auto tx = dynamic_cast<variables::Tx_DynamicElement *> (v);
+    auto session = dynamic_cast<variables::Session_DynamicElement *> (v);
+    auto ip = dynamic_cast<variables::Ip_DynamicElement *> (v);
+    auto resource = dynamic_cast<variables::Resource_DynamicElement *> (v);
+    auto global = dynamic_cast<variables::Global_DynamicElement *> (v);
+    auto user = dynamic_cast<variables::User_DynamicElement *> (v);
     if (tx) {
         m_variableNameExpanded = tx->m_string->evaluate(t, rule);
     } else if (session) {
@@ -113,7 +106,8 @@ bool SetVar::evaluate(Rule *rule, Transaction *t) {
 
         try {
             std::vector<const VariableValue *> l;
-            m_variable->evaluate(t, rule, &l);
+            RuleWithOperator *rr = dynamic_cast<RuleWithOperator *>(rule);
+            m_variable->evaluate(t, rr, &l);
             if (l.size() == 0) {
                 value = 0;
             } else {
