@@ -13,42 +13,20 @@
  *
  */
 
-#include <string>
-
-#include "modsecurity/actions/action.h"
-#include "src/actions/transformations/transformation.h"
-
 #ifndef SRC_ACTIONS_TRANSFORMATIONS_SQL_HEX_DECODE_H_
 #define SRC_ACTIONS_TRANSFORMATIONS_SQL_HEX_DECODE_H_
 
-#ifdef __cplusplus
-namespace modsecurity {
-class Transaction;
+#include "transformation.h"
 
-namespace actions {
-namespace transformations {
+namespace modsecurity::actions::transformations {
 
 class SqlHexDecode : public Transformation {
  public:
-    explicit SqlHexDecode(const std::string &action)  : Transformation(action) { }
+    using Transformation::Transformation;
 
-    std::string evaluate(const std::string &exp,
-        Transaction *transaction) override;
-
-    static int inplace(unsigned char *data, int len);
-
-    static int mytolower(int ch) {
-        if (ch >= 'A' && ch <= 'Z')
-            return ('a' + ch - 'A');
-        else
-            return ch;
-    }
+    bool transform(std::string &value, const Transaction *trans) const override;
 };
 
-}  // namespace transformations
-}  // namespace actions
-}  // namespace modsecurity
-
-#endif
+}  // namespace modsecurity::actions::transformations
 
 #endif  // SRC_ACTIONS_TRANSFORMATIONS_SQL_HEX_DECODE_H_
