@@ -19,7 +19,7 @@
 #include <list>
 
 #include "src/operators/operator.h"
-#include "others/libinjection/src/libinjection.h"
+#include "libinjection/src/libinjection.h"
 
 namespace modsecurity {
 namespace operators {
