@@ -1,6 +1,6 @@
 /*
  * ModSecurity, http://www.modsecurity.org/
- * Copyright (c) 2015 Trustwave Holdings, Inc. (http://www.trustwave.com/)
+ * Copyright (c) 2015 - 2021 Trustwave Holdings, Inc. (http://www.trustwave.com/)
  *
  * You may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
@@ -31,7 +31,7 @@ class IpMatch : public Operator {
     /** @ingroup ModSecurity_Operator */
     explicit IpMatch(std::unique_ptr<RunTimeString> param)
         : Operator("IpMatch", std::move(param)) { }
-    IpMatch(std::string n, std::unique_ptr<RunTimeString> param)
+    IpMatch(const std::string &n, std::unique_ptr<RunTimeString> param)
         : Operator(n, std::move(param)) { }
 
     bool evaluate(Transaction *transaction, const std::string &input) override;
