@@ -17,6 +17,7 @@
 
 #include <stdio.h>
 
+#include <cassert>
 #include <algorithm>
 #include <iostream>
 #include <string>
@@ -24,6 +25,7 @@
 #include <list>
 #include <utility>
 #include <memory>
+#include <cassert>
 
 #include "modsecurity/rules_set.h"
 #include "src/operators/operator.h"
@@ -86,45 +88,50 @@ RuleWithActions::RuleWithActions(
 
     if (actions) {
         for (Action *a : *actions) {
-            if (a->action_kind == Action::ConfigurationKind) {
-                a->evaluate(this, NULL);
-                delete a;
-
-            } else if (a->action_kind == Action::RunTimeOnlyIfMatchKind) {
-                if (dynamic_cast<actions::Capture *>(a)) {
-                    m_containsCaptureAction = true;
+            switch (a->action_kind) {
+                case Action::Kind::ConfigurationKind:
+                    a->evaluate(this, NULL);
                     delete a;
-                } else if (dynamic_cast<actions::MultiMatch *>(a)) {
-                    m_containsMultiMatchAction = true;
-                    delete a;
-                } else if (dynamic_cast<actions::Severity *>(a)) {
-                    m_severity = dynamic_cast<actions::Severity *>(a);
-                } else if (dynamic_cast<actions::LogData *>(a)) {
-                    m_logData = dynamic_cast<actions::LogData*>(a);
-                } else if (dynamic_cast<actions::Msg *>(a)) {
-                    m_msg = dynamic_cast<actions::Msg*>(a);
-                } else if (dynamic_cast<actions::SetVar *>(a)) {
-                    m_actionsSetVar.push_back(
-                        dynamic_cast<actions::SetVar *>(a));
-                } else if (dynamic_cast<actions::Tag *>(a)) {
-                    m_actionsTag.push_back(dynamic_cast<actions::Tag *>(a));
-                } else if (dynamic_cast<actions::Block *>(a)) {
-                    m_actionsRuntimePos.push_back(a);
-                    m_containsStaticBlockAction = true;
-                } else if (a->isDisruptive() == true) {
-                    if (m_disruptiveAction != nullptr) {
-                        delete m_disruptiveAction;
-                        m_disruptiveAction = nullptr;
+                    break;
+                case Action::Kind::RunTimeOnlyIfMatchKind:
+                    if (dynamic_cast<actions::Capture *>(a)) {
+                        m_containsCaptureAction = true;
+                        delete a;
+                    } else if (dynamic_cast<actions::MultiMatch *>(a)) {
+                        m_containsMultiMatchAction = true;
+                        delete a;
+                    } else if (auto sa = dynamic_cast<actions::Severity *>(a)) {
+                        m_severity = sa;
+                    } else if (auto lda = dynamic_cast<actions::LogData *>(a)) {
+                        m_logData = lda;
+                    } else if (auto ma = dynamic_cast<actions::Msg *>(a)) {
+                        m_msg = ma;
+                    } else if (auto sva = dynamic_cast<actions::SetVar *>(a)) {
+                        m_actionsSetVar.push_back(sva);
+                    } else if (auto ta = dynamic_cast<actions::Tag *>(a)) {
+                        m_actionsTag.push_back(ta);
+                    } else if (dynamic_cast<actions::Block *>(a)) {
+                        m_actionsRuntimePos.push_back(a);
+                        m_containsStaticBlockAction = true;
+                    } else if (a->isDisruptive() == true) {
+                        if (m_disruptiveAction != nullptr) {
+                            delete m_disruptiveAction;
+                            m_disruptiveAction = nullptr;
+                        }
+                        m_disruptiveAction = a;
+                    } else {
+                        m_actionsRuntimePos.push_back(a);
                     }
-                    m_disruptiveAction = a;
-                } else {
-                    m_actionsRuntimePos.push_back(a);
-                }
-            } else {
-                delete a;
-                std::cout << "General failure, action: " << a->m_name;
-                std::cout << " has an unknown type." << std::endl;
-                throw;
+                    break;
+                default:
+                    std::cout << "General failure, action: " << a->m_name;
+                    std::cout << " has an unknown type." << std::endl;
+                    delete a;
+                    #ifdef NDEBUG
+                    break;
+                    #else
+                    assert(false);
+                    #endif
             }
         }
         delete actions;
@@ -172,9 +179,7 @@ RuleWithActions::~RuleWithActions() {
 
 
 bool RuleWithActions::evaluate(Transaction *transaction) {
-    RuleMessage rm(this, transaction);
-    std::shared_ptr<RuleMessage> rm2 = std::make_shared<RuleMessage>(&rm);
-    return evaluate(transaction, rm2);
+    return evaluate(transaction, std::make_shared<RuleMessage>(this, transaction));
 }
 
 
@@ -208,7 +213,7 @@ void RuleWithActions::executeActionsIndependentOfChainedRuleResult(Transaction *
         if (m_ruleId != b.first) {
             continue;
         }
-        actions::Action *a = dynamic_cast<actions::Action*>(b.second.get());
+        actions::Action *a = b.second.get();
         if (a->isDisruptive() == true && *a->m_name.get() == "block") {
             ms_dbg_a(trans, 9, "Rule contains a `block' action");
                 *containsBlock = true;
@@ -241,8 +246,8 @@ void RuleWithActions::executeActionsAfterFullMatch(Transaction *trans,
     bool containsBlock, std::shared_ptr<RuleMessage> ruleMessage) {
     bool disruptiveAlreadyExecuted = false;
 
-    for (auto &a : trans->m_rules->m_defaultActions[getPhase()]) {
-        if (a.get()->action_kind != actions::Action::RunTimeOnlyIfMatchKind) {
+    for (const auto &a : trans->m_rules->m_defaultActions[getPhase()]) { // cppcheck-suppress ctunullpointer
+        if (a.get()->action_kind != actions::Action::Kind::RunTimeOnlyIfMatchKind) {
             continue;
         }
         if (!a.get()->isDisruptive()) {
@@ -261,7 +266,7 @@ void RuleWithActions::executeActionsAfterFullMatch(Transaction *trans,
         if (m_ruleId != b.first) {
             continue;
         }
-        actions::Action *a = dynamic_cast<actions::Action*>(b.second.get());
+        actions::Action *a = b.second.get();
         executeAction(trans, containsBlock, ruleMessage, a, false);
         disruptiveAlreadyExecuted = true;
     }
@@ -319,50 +324,42 @@ void RuleWithActions::executeAction(Transaction *trans,
 
 
 inline void RuleWithActions::executeTransformation(
-    actions::transformations::Transformation *a,
-    std::shared_ptr<std::string> *value,
-    Transaction *trans,
-    TransformationResults *ret,
-    std::string *path,
-    int *nth) const {
+    const actions::transformations::Transformation &a,
+    std::string &value,
+    const Transaction *trans,
+    TransformationResults &ret,
+    std::string &path,
+    int &nth) const {
 
-    std::string *oldValue = (*value).get();
-    std::string newValue = a->evaluate(*oldValue, trans);
-
-    if (newValue != *oldValue) {
-        std::shared_ptr<std::string> u(new std::string(newValue));
-        if (m_containsMultiMatchAction) {
-            ret->push_back(std::make_pair(u, a->m_name));
-            (*nth)++;
-        }
-        *value = u;
+    if (a.transform(value, trans) &&
+        m_containsMultiMatchAction) {
+        ret.emplace_back(value, a.m_name);
+        nth++;
     }
 
-    if (path->empty()) {
-        path->append(*a->m_name.get());
+    if (path.empty()) {
+        path.append(*a.m_name.get());
     } else {
-        path->append("," + *a->m_name.get());
+        path.append("," + *a.m_name.get());
     }
 
     ms_dbg_a(trans, 9, " T (" + \
-        std::to_string(*nth) + ") " + \
-        *a->m_name.get() + ": \"" + \
-        utils::string::limitTo(80, newValue) +"\"");
+        std::to_string(nth) + ") " + \
+        *a.m_name.get() + ": \"" + \
+        utils::string::limitTo(80, value) +"\"");
 }
 
 void RuleWithActions::executeTransformations(
-    Transaction *trans, const std::string &in, TransformationResults &ret) {
+    const Transaction *trans, const std::string &in, TransformationResults &ret) {
     int none = 0;
     int transformations = 0;
-    std::string path("");
-    std::shared_ptr<std::string> value =
-        std::shared_ptr<std::string>(new std::string(in));
+    std::string path;
+    auto value = in;
 
     if (m_containsMultiMatchAction == true) {
         /* keep the original value */
-        ret.push_back(std::make_pair(
-            std::shared_ptr<std::string>(new std::string(*value)),
-            std::shared_ptr<std::string>(new std::string(path))));
+        ret.emplace_back(value,
+                       std::make_shared<std::string>(path));
     }
 
     for (Action *a : m_transformations) {
@@ -377,22 +374,23 @@ void RuleWithActions::executeTransformations(
     if (none == 0) {
         for (auto &a : trans->m_rules->m_defaultActions[getPhase()]) {
             if (a->action_kind \
-                != actions::Action::RunTimeBeforeMatchAttemptKind) {
+                != actions::Action::Kind::RunTimeBeforeMatchAttemptKind) {
                 continue;
             }
 
             // FIXME: here the object needs to be a transformation already.
-            Transformation *t = dynamic_cast<Transformation *>(a.get());
-            executeTransformation(t, &value, trans, &ret, &path,
-                &transformations);
+            auto t = dynamic_cast<const Transformation*>(a.get());
+            assert(t != nullptr);
+            executeTransformation(*t, value, trans, ret, path,
+                transformations);
         }
     }
 
-    for (Transformation *a : m_transformations) {
+    for (const Transformation *a : m_transformations) {
+        assert(a != nullptr);
         if (none == 0) {
-            Transformation *t = dynamic_cast<Transformation *>(a);
-            executeTransformation(t, &value, trans, &ret, &path,
-                &transformations);
+            executeTransformation(*a, value, trans, ret, path,
+                transformations);
         }
         if (a->m_isNone) {
             none--;
@@ -406,7 +404,8 @@ void RuleWithActions::executeTransformations(
         if (m_ruleId != b.first) {
             continue;
         }
-        Transformation *a = dynamic_cast<Transformation*>(b.second.get());
+        auto a = dynamic_cast<const Transformation*>(b.second.get());
+        assert(a != nullptr);
         if (a->m_isNone) {
             none++;
         }
@@ -417,11 +416,11 @@ void RuleWithActions::executeTransformations(
         if (m_ruleId != b.first) {
             continue;
         }
-        Transformation *a = dynamic_cast<Transformation*>(b.second.get());
+        auto a = dynamic_cast<const Transformation*>(b.second.get());
+        assert(a != nullptr);
         if (none == 0) {
-            Transformation *t = dynamic_cast<Transformation *>(a);
-            executeTransformation(t, &value, trans, &ret, &path,
-                &transformations);
+            executeTransformation(*a, value, trans, ret, path,
+                transformations);
         }
         if (a->m_isNone) {
             none--;
@@ -435,9 +434,8 @@ void RuleWithActions::executeTransformations(
     }
 
     if (!m_containsMultiMatchAction) {
-        ret.push_back(std::make_pair(
-            std::shared_ptr<std::string>(new std::string(*value)),
-            std::shared_ptr<std::string>(new std::string(path))));
+        ret.emplace_back(value,
+                       std::make_shared<std::string>(path));
     }
 }
 
@@ -475,7 +473,7 @@ std::vector<actions::Action *> RuleWithActions::getActionsByName(const std::stri
         if (m_ruleId != b.first) {
             continue;
         }
-        actions::Action *z = dynamic_cast<actions::Action*>(b.second.get());
+        actions::Action *z = b.second.get();
         if (*z->m_name.get() == name) {
             ret.push_back(z);
         }
@@ -485,7 +483,7 @@ std::vector<actions::Action *> RuleWithActions::getActionsByName(const std::stri
         if (m_ruleId != b.first) {
             continue;
         }
-        actions::Action *z = dynamic_cast<actions::Action*>(b.second.get());
+        actions::Action *z = b.second.get();
         if (*z->m_name.get() == name) {
             ret.push_back(z);
         }
