@@ -1,6 +1,6 @@
 /*
  * ModSecurity, http://www.modsecurity.org/
- * Copyright (c) 2015 Trustwave Holdings, Inc. (http://www.trustwave.com/)
+ * Copyright (c) 2015 - 2021 Trustwave Holdings, Inc. (http://www.trustwave.com/)
  *
  * You may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
@@ -46,8 +46,8 @@ class UniqueId {
     }
 
     void fillUniqueId();
-    std::string const machineName();
-    std::string const ethernetMacAddress();
+    static std::string machineName();
+    static std::string ethernetMacAddress();
 
     std::string uniqueId_str;
 
